Crate netgauze_parse_utils

Crate netgauze_parse_utils 

Traits for Ser/Deser wire protocols

Modules

common
error
reader
traits

Macros

impl_from_io_error
Generates From<std::io::Error> for one or more serializer error enums.

Traits

WritablePdu
Generic trait for Writable Protocol Data Unit that doesn’t need any external input while writing the packet.
WritablePduWithOneInput
Generic trait for Writable Protocol Data Unit that doesn’t need any external input while writing the packet.
WritablePduWithTwoInputs
Generic trait for Writable Protocol Data Unit that doesn’t need any external input while writing the packet.