Traits for Ser/Deser wire protocols
Modules
Macros
- impl_
from_ io_ error - Generates
From<std::io::Error>for one or more serializer error enums.
Traits
- Writable
Pdu - Generic trait for Writable Protocol Data Unit that doesn’t need any external input while writing the packet.
- Writable
PduWith OneInput - Generic trait for Writable Protocol Data Unit that doesn’t need any external input while writing the packet.
- Writable
PduWith TwoInputs - Generic trait for Writable Protocol Data Unit that doesn’t need any external input while writing the packet.